pub struct PiiConfig {
pub rules: BTreeMap<String, RuleSpec>,
pub vars: Vars,
pub applications: BTreeMap<SelectorSpec, Vec<String>>,
/* private fields */
}Expand description
A set of named rule configurations.
Fields
rules: BTreeMap<String, RuleSpec>A map of custom PII rules.
vars: VarsParameters for PII rules.
applications: BTreeMap<SelectorSpec, Vec<String>>Mapping of selectors to rules.
Implementations
Sourceimpl PiiConfig
impl PiiConfig
Sourcepub fn compiled(&self) -> &CompiledPiiConfig
pub fn compiled(&self) -> &CompiledPiiConfig
Get a representation of this PiiConfig that is more (CPU-)efficient for processing.
This can be computationally expensive when called for the first time. The result is cached internally and reused on the second call.
Sourcepub fn compiled_uncached(&self) -> CompiledPiiConfig
pub fn compiled_uncached(&self) -> CompiledPiiConfig
Like compiled but without internal caching.